Skip to contents

Example reference allele read count data for testing and demonstration purposes.

Usage

example_read0

Format

A matrix of reference allele read counts with 200 hosts and 96 SNPs

Simulated data for package testing