Skip to contents

Example alternate allele read count data for testing and demonstration purposes.

Usage

example_read1

Format

A matrix of alternate allele read counts with 200 hosts and 96 SNPs

Simulated data for package testing