R/data_handling.R
example_read0.Rd
Example reference allele read count data for testing and demonstration purposes.
example_read0
A matrix of reference allele read counts with 200 hosts and 96 SNPs
Simulated data for package testing