R/data_handling.R
example_read1.Rd
Example alternate allele read count data for testing and demonstration purposes.
example_read1
A matrix of alternate allele read counts with 200 hosts and 96 SNPs
Simulated data for package testing