Plot convergence diagnostics
Arguments
- results
SNP-Slice results object
- type
Type of plot ("logpost", "kstar", "n_strains")
- additional_burnin
Number of additional stored samples to discard from the start of the retained chain. The retained chain is already post-burn-in, so this defaults to 0.
- chain
Which chain of a multi-chain run to use.
NULL(default) uses the top-level estimates, i.e. the chain with the highest MAP log posterior (results$best_chain). Give an index to analyse a specific chain instead; seecompare_chains.